Class: RusticiSoftwareCloudV2::DispatchSchema

Inherits:
Object
  • Object
show all
Defined in:
lib/rustici_software_cloud_v2/models/dispatch_schema.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DispatchSchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'destinationId')
    self.destination_id = attributes[:'destinationId']
  end

  if attributes.has_key?(:'destinationName')
    self.destination_name = attributes[:'destinationName']
  end

  if attributes.has_key?(:'courseId')
    self.course_id = attributes[:'courseId']
  end

  if attributes.has_key?(:'courseTitle')
    self.course_title = attributes[:'courseTitle']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'allowNewRegistrations')
    self.allow_new_registrations = attributes[:'allowNewRegistrations']
  end

  if attributes.has_key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.has_key?(:'instanced')
    self.instanced = attributes[:'instanced']
  end

  if attributes.has_key?(:'registrationCap')
    self.registration_cap = attributes[:'registrationCap']
  end

  if attributes.has_key?(:'registrationCount')
    self.registration_count = attributes[:'registrationCount']
  end

  if attributes.has_key?(:'registrationResetDate')
    self.registration_reset_date = attributes[:'registrationResetDate']
  end

  if attributes.has_key?(:'expirationDate')
    self.expiration_date = attributes[:'expirationDate']
  end

  if attributes.has_key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.has_key?(:'notes')
    self.notes = attributes[:'notes']
  end
end

Instance Attribute Details

#allow_new_registrationsObject

If true, then new registrations can be created for this dispatch.



34
35
36
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 34

def allow_new_registrations
  @allow_new_registrations
end

#course_idObject

Serialized external package ID.



24
25
26
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 24

def course_id
  @course_id
end

#course_titleObject

Title of this dispatched course



27
28
29
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 27

def course_title
  @course_title
end

#createdObject

Returns the value of attribute created.



31
32
33
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 31

def created
  @created
end

#destination_idObject

Destination ID.



18
19
20
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 18

def destination_id
  @destination_id
end

#destination_nameObject

Name of the destination housing this dispatch



21
22
23
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 21

def destination_name
  @destination_name
end

#emailObject

SCORM Cloud user e-mail associated with this dispatch. If this is not provided, it will default to the owner of the Realm.



58
59
60
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 58

def email
  @email
end

#enabledObject

If false, the dispatch can not be launched.



37
38
39
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 37

def enabled
  @enabled
end

#expiration_dateObject

The ISO 8601 TimeStamp (defaults to UTC) after which this dispatch will be disabled. An empty value will represent no expiration date.



52
53
54
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 52

def expiration_date
  @expiration_date
end

#instancedObject

If true, then a new registration instance will be created if the client LMS doesn’t provide launch data for an existing one. Otherwise, the same instance will always be used for the given cmi.learner_id.



40
41
42
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 40

def instanced
  @instanced
end

#notesObject

Any provided notes about this dispatch.



61
62
63
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 61

def notes
  @notes
end

#registration_capObject

The maximum number of registrations that can be created for this dispatch, where ‘0’ means ‘unlimited registrations’.



43
44
45
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 43

def registration_cap
  @registration_cap
end

#registration_countObject

The current number of registrations that have been created for this dispatch.



46
47
48
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 46

def registration_count
  @registration_count
end

#registration_reset_dateObject

The ISO 8601 TimeStamp (defaults to UTC) at which the registration count for this dispatch was reset.



49
50
51
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 49

def registration_reset_date
  @registration_reset_date
end

#tagsObject

The tags to associate with this Dispatch.



55
56
57
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 55

def tags
  @tags
end

#updatedObject

Returns the value of attribute updated.



29
30
31
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 29

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 64

def self.attribute_map
  {
    :'destination_id' => :'destinationId',
    :'destination_name' => :'destinationName',
    :'course_id' => :'courseId',
    :'course_title' => :'courseTitle',
    :'updated' => :'updated',
    :'created' => :'created',
    :'allow_new_registrations' => :'allowNewRegistrations',
    :'enabled' => :'enabled',
    :'instanced' => :'instanced',
    :'registration_cap' => :'registrationCap',
    :'registration_count' => :'registrationCount',
    :'registration_reset_date' => :'registrationResetDate',
    :'expiration_date' => :'expirationDate',
    :'tags' => :'tags',
    :'email' => :'email',
    :'notes' => :'notes'
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 86

def self.swagger_types
  {
    :'destination_id' => :'String',
    :'destination_name' => :'String',
    :'course_id' => :'String',
    :'course_title' => :'String',
    :'updated' => :'DateTime',
    :'created' => :'DateTime',
    :'allow_new_registrations' => :'BOOLEAN',
    :'enabled' => :'BOOLEAN',
    :'instanced' => :'BOOLEAN',
    :'registration_cap' => :'Integer',
    :'registration_count' => :'Integer',
    :'registration_reset_date' => :'DateTime',
    :'expiration_date' => :'DateTime',
    :'tags' => :'Array<String>',
    :'email' => :'String',
    :'notes' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      destination_id == o.destination_id &&
      destination_name == o.destination_name &&
      course_id == o.course_id &&
      course_title == o.course_title &&
      updated == o.updated &&
      created == o.created &&
      allow_new_registrations == o.allow_new_registrations &&
      enabled == o.enabled &&
      instanced == o.instanced &&
      registration_cap == o.registration_cap &&
      registration_count == o.registration_count &&
      registration_reset_date == o.registration_reset_date &&
      expiration_date == o.expiration_date &&
      tags == o.tags &&
      email == o.email &&
      notes == o.notes
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 255

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = RusticiSoftwareCloudV2.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 321

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 234

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 227

def hash
  [destination_id, destination_name, course_id, course_title, updated, created, allow_new_registrations, enabled, instanced, registration_cap, registration_count, registration_reset_date, expiration_date, tags, email, notes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 184

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 301

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



295
296
297
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 295

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
# File 'lib/rustici_software_cloud_v2/models/dispatch_schema.rb', line 191

def valid?
  true
end