Class: RusticiSoftwareCloudV2::PublicInvitationSchema

Inherits:
Object
  • Object
show all
Defined in:
lib/rustici_software_cloud_v2/models/public_invitation_schema.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PublicInvitationSchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'courseId')
    self.course_id = attributes[:'courseId']
  end

  if attributes.has_key?(:'courseTitle')
    self.course_title = attributes[:'courseTitle']
  end

  if attributes.has_key?(:'allowLaunch')
    self.allow_launch = attributes[:'allowLaunch']
  end

  if attributes.has_key?(:'allowNewRegistrations')
    self.allow_new_registrations = attributes[:'allowNewRegistrations']
  end

  if attributes.has_key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.has_key?(:'createDate')
    self.create_date = attributes[:'createDate']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'postBack')
    self.post_back = attributes[:'postBack']
  end

  if attributes.has_key?(:'expirationDate')
    self.expiration_date = attributes[:'expirationDate']
  end

  if attributes.has_key?(:'registrationCap')
    self.registration_cap = attributes[:'registrationCap']
  end

  if attributes.has_key?(:'registrationCount')
    self.registration_count = attributes[:'registrationCount']
  end
end

Instance Attribute Details

#allow_launchObject

Determines if learners are allowed to launch the invitation. If false, the invitation is disabled and no new or existing learners are allowed to launch it.



27
28
29
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 27

def allow_launch
  @allow_launch
end

#allow_new_registrationsObject

Determines if new registrations can be created for this public invitation. If false, no new registrations can be created for the invitation, so only learners with existing registrations can access the invitation.



30
31
32
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 30

def allow_new_registrations
  @allow_new_registrations
end

#course_idObject

Course Id for this Invitation.



21
22
23
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 21

def course_id
  @course_id
end

#course_titleObject

Title of the course associated with this invitation.



24
25
26
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 24

def course_title
  @course_title
end

#create_dateObject

The create date for the invitation



36
37
38
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 36

def create_date
  @create_date
end

#expiration_dateObject

The ISO 8601 TimeStamp (defaults to UTC) after which this invitation will expire and can no longer be launched. An empty value will represent no expiration date.



44
45
46
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 44

def expiration_date
  @expiration_date
end

#idObject

The invitationId for this invitation.



18
19
20
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 18

def id
  @id
end

#post_backObject

Specifies a URL for which to post activity and status data in real time as the course is completed



41
42
43
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 41

def post_back
  @post_back
end

#registration_capObject

Integer value that represents the maximum number of registrations that can be created for a public invitation. Setting this value to ‘0’ allows an unlimited amount of registrations to be created for the invitation.



47
48
49
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 47

def registration_cap
  @registration_cap
end

#registration_countObject

The count of registrations for this invitation



50
51
52
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 50

def registration_count
  @registration_count
end

#updatedObject

Returns the value of attribute updated.



38
39
40
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 38

def updated
  @updated
end

#urlObject

The launch URL for the invitation



33
34
35
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 33

def url
  @url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'course_id' => :'courseId',
    :'course_title' => :'courseTitle',
    :'allow_launch' => :'allowLaunch',
    :'allow_new_registrations' => :'allowNewRegistrations',
    :'url' => :'url',
    :'create_date' => :'createDate',
    :'updated' => :'updated',
    :'post_back' => :'postBack',
    :'expiration_date' => :'expirationDate',
    :'registration_cap' => :'registrationCap',
    :'registration_count' => :'registrationCount'
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 71

def self.swagger_types
  {
    :'id' => :'String',
    :'course_id' => :'String',
    :'course_title' => :'String',
    :'allow_launch' => :'BOOLEAN',
    :'allow_new_registrations' => :'BOOLEAN',
    :'url' => :'String',
    :'create_date' => :'DateTime',
    :'updated' => :'DateTime',
    :'post_back' => :'PostBackSchema',
    :'expiration_date' => :'DateTime',
    :'registration_cap' => :'Integer',
    :'registration_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      course_id == o.course_id &&
      course_title == o.course_title &&
      allow_launch == o.allow_launch &&
      allow_new_registrations == o.allow_new_registrations &&
      url == o.url &&
      create_date == o.create_date &&
      updated == o.updated &&
      post_back == o.post_back &&
      expiration_date == o.expiration_date &&
      registration_cap == o.registration_cap &&
      registration_count == o.registration_count
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 214

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = RusticiSoftwareCloudV2.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 193

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 186

def hash
  [id, course_id, course_title, allow_launch, allow_new_registrations, url, create_date, updated, post_back, expiration_date, registration_cap, registration_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 147

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 260

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



254
255
256
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 254

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
# File 'lib/rustici_software_cloud_v2/models/public_invitation_schema.rb', line 154

def valid?
  true
end