Class: RusticiSoftwareCloudV2::ReportingApi
- Inherits:
-
Object
- Object
- RusticiSoftwareCloudV2::ReportingApi
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/rustici_software_cloud_v2/api/reporting_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_account_info(opts = {}) ⇒ ReportageAccountInfoSchema
Get account information Returns all of the account information for the specified application.
-
#get_account_info_with_http_info(opts = {}) ⇒ Array<(ReportageAccountInfoSchema, Fixnum, Hash)>
Get account information Returns all of the account information for the specified application.
-
#get_reportage_auth_token(nav_permission, opts = {}) ⇒ ReportageAuthTokenSchema
Get a Reportage session authentication token Returns a session authentication token to use when launching Reportage.
-
#get_reportage_auth_token_with_http_info(nav_permission, opts = {}) ⇒ Array<(ReportageAuthTokenSchema, Fixnum, Hash)>
Get a Reportage session authentication token Returns a session authentication token to use when launching Reportage.
-
#get_reportage_link(auth, report_url, opts = {}) ⇒ ReportageLinkSchema
Get a link to a page in Reportage with the given permissions Returns the link to use for viewing Reportage.
-
#get_reportage_link_with_http_info(auth, report_url, opts = {}) ⇒ Array<(ReportageLinkSchema, Fixnum, Hash)>
Get a link to a page in Reportage with the given permissions Returns the link to use for viewing Reportage.
-
#initialize(api_client = ApiClient.default) ⇒ ReportingApi
constructor
A new instance of ReportingApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ReportingApi
Returns a new instance of ReportingApi.
18 19 20 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 18 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#get_account_info(opts = {}) ⇒ ReportageAccountInfoSchema
Get account information Returns all of the account information for the specified application.
28 29 30 31 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 28 def get_account_info(opts = {}) data, _status_code, _headers = get_account_info_with_http_info(opts) data end |
#get_account_info_with_http_info(opts = {}) ⇒ Array<(ReportageAccountInfoSchema, Fixnum, Hash)>
Get account information Returns all of the account information for the specified application.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 37 def get_account_info_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportingApi.get_account_info ...' end # resource path local_var_path = '/reporting/accountInfo' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['APP_NORMAL', 'OAUTH'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ReportageAccountInfoSchema') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportingApi#get_account_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_reportage_auth_token(nav_permission, opts = {}) ⇒ ReportageAuthTokenSchema
Get a Reportage session authentication token Returns a session authentication token to use when launching Reportage.
79 80 81 82 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 79 def get_reportage_auth_token(, opts = {}) data, _status_code, _headers = get_reportage_auth_token_with_http_info(, opts) data end |
#get_reportage_auth_token_with_http_info(nav_permission, opts = {}) ⇒ Array<(ReportageAuthTokenSchema, Fixnum, Hash)>
Get a Reportage session authentication token Returns a session authentication token to use when launching Reportage.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 90 def get_reportage_auth_token_with_http_info(, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportingApi.get_reportage_auth_token ...' end # verify the required parameter 'nav_permission' is set if .nil? fail ArgumentError, "Missing the required parameter 'nav_permission' when calling ReportingApi.get_reportage_auth_token" end # resource path local_var_path = '/reporting/reportageAuth' # query parameters query_params = {} query_params[:'navPermission'] = query_params[:'admin'] = opts[:'admin'] if !opts[:'admin'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['APP_NORMAL', 'OAUTH'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ReportageAuthTokenSchema') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportingApi#get_reportage_auth_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_reportage_link(auth, report_url, opts = {}) ⇒ ReportageLinkSchema
Get a link to a page in Reportage with the given permissions Returns the link to use for viewing Reportage. In order to generate a link, GetReportageAuthToken will need to be called to generate an auth token with the necessary permissions.
138 139 140 141 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 138 def get_reportage_link(auth, report_url, opts = {}) data, _status_code, _headers = get_reportage_link_with_http_info(auth, report_url, opts) data end |
#get_reportage_link_with_http_info(auth, report_url, opts = {}) ⇒ Array<(ReportageLinkSchema, Fixnum, Hash)>
Get a link to a page in Reportage with the given permissions Returns the link to use for viewing Reportage. In order to generate a link, GetReportageAuthToken will need to be called to generate an auth token with the necessary permissions.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/rustici_software_cloud_v2/api/reporting_api.rb', line 149 def get_reportage_link_with_http_info(auth, report_url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportingApi.get_reportage_link ...' end # verify the required parameter 'auth' is set if auth.nil? fail ArgumentError, "Missing the required parameter 'auth' when calling ReportingApi.get_reportage_link" end # verify the required parameter 'report_url' is set if report_url.nil? fail ArgumentError, "Missing the required parameter 'report_url' when calling ReportingApi.get_reportage_link" end # resource path local_var_path = '/reporting/reportageLink' # query parameters query_params = {} query_params[:'auth'] = auth query_params[:'reportUrl'] = report_url # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['APP_NORMAL', 'OAUTH'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ReportageLinkSchema') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportingApi#get_reportage_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |